"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudfunctionsFunctionXEventTriggerXFailurePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETRY_FIELD_NUMBER: builtins.int
    retry: builtins.bool
    def __init__(
        self,
        *,
        retry: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["retry", b"retry"]) -> None: ...

global___CloudfunctionsFunctionXEventTriggerXFailurePolicy = CloudfunctionsFunctionXEventTriggerXFailurePolicy

@typing_extensions.final
class CloudfunctionsFunctionXEventTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    FAILURE_POLICY_FIELD_NUMBER: builtins.int
    event_type: builtins.str
    resource: builtins.str
    @property
    def failure_policy(self) -> global___CloudfunctionsFunctionXEventTriggerXFailurePolicy: ...
    def __init__(
        self,
        *,
        event_type: builtins.str = ...,
        resource: builtins.str = ...,
        failure_policy: global___CloudfunctionsFunctionXEventTriggerXFailurePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure_policy", b"failure_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_type", b"event_type", "failure_policy", b"failure_policy", "resource", b"resource"]) -> None: ...

global___CloudfunctionsFunctionXEventTrigger = CloudfunctionsFunctionXEventTrigger

@typing_extensions.final
class CloudfunctionsFunctionXSecretEnvironmentVariables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    key: builtins.str
    project_id: builtins.str
    secret: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        project_id: builtins.str = ...,
        secret: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "project_id", b"project_id", "secret", b"secret", "version", b"version"]) -> None: ...

global___CloudfunctionsFunctionXSecretEnvironmentVariables = CloudfunctionsFunctionXSecretEnvironmentVariables

@typing_extensions.final
class CloudfunctionsFunctionXSecretVolumesXVersions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    path: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "version", b"version"]) -> None: ...

global___CloudfunctionsFunctionXSecretVolumesXVersions = CloudfunctionsFunctionXSecretVolumesXVersions

@typing_extensions.final
class CloudfunctionsFunctionXSecretVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    project_id: builtins.str
    secret: builtins.str
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudfunctionsFunctionXSecretVolumesXVersions]: ...
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        project_id: builtins.str = ...,
        secret: builtins.str = ...,
        versions: collections.abc.Iterable[global___CloudfunctionsFunctionXSecretVolumesXVersions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "project_id", b"project_id", "secret", b"secret", "versions", b"versions"]) -> None: ...

global___CloudfunctionsFunctionXSecretVolumes = CloudfunctionsFunctionXSecretVolumes

@typing_extensions.final
class CloudfunctionsFunctionXSourceRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYED_URL_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    deployed_url: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        deployed_url: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployed_url", b"deployed_url", "url", b"url"]) -> None: ...

global___CloudfunctionsFunctionXSourceRepository = CloudfunctionsFunctionXSourceRepository

@typing_extensions.final
class CloudfunctionsFunctionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___CloudfunctionsFunctionXTimeouts = CloudfunctionsFunctionXTimeouts

@typing_extensions.final
class CloudfunctionsFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BuildEnvironmentVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EnvironmentVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AVAILABLE_MEMORY_MB_FIELD_NUMBER: builtins.int
    BUILD_ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCKER_REGISTRY_FIELD_NUMBER: builtins.int
    DOCKER_REPOSITORY_FIELD_NUMBER: builtins.int
    ENTRY_POINT_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    HTTPS_TRIGGER_SECURITY_LEVEL_FIELD_NUMBER: builtins.int
    HTTPS_TRIGGER_URL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INGRESS_SETTINGS_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAX_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_INSTANCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    SOURCE_ARCHIVE_BUCKET_FIELD_NUMBER: builtins.int
    SOURCE_ARCHIVE_OBJECT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TRIGGER_HTTP_FIELD_NUMBER: builtins.int
    VPC_CONNECTOR_FIELD_NUMBER: builtins.int
    VPC_CONNECTOR_EGRESS_SETTINGS_FIELD_NUMBER: builtins.int
    EVENT_TRIGGER_FIELD_NUMBER: builtins.int
    SECRET_ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
    SECRET_VOLUMES_FIELD_NUMBER: builtins.int
    SOURCE_REPOSITORY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_memory_mb: builtins.float
    @property
    def build_environment_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    docker_registry: builtins.str
    docker_repository: builtins.str
    entry_point: builtins.str
    @property
    def environment_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    https_trigger_security_level: builtins.str
    https_trigger_url: builtins.str
    id: builtins.str
    ingress_settings: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    max_instances: builtins.float
    min_instances: builtins.float
    name: builtins.str
    project: builtins.str
    region: builtins.str
    runtime: builtins.str
    service_account_email: builtins.str
    source_archive_bucket: builtins.str
    source_archive_object: builtins.str
    timeout: builtins.float
    trigger_http: builtins.bool
    vpc_connector: builtins.str
    vpc_connector_egress_settings: builtins.str
    @property
    def event_trigger(self) -> global___CloudfunctionsFunctionXEventTrigger: ...
    @property
    def secret_environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudfunctionsFunctionXSecretEnvironmentVariables]: ...
    @property
    def secret_volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudfunctionsFunctionXSecretVolumes]: ...
    @property
    def source_repository(self) -> global___CloudfunctionsFunctionXSourceRepository: ...
    @property
    def timeouts(self) -> global___CloudfunctionsFunctionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_memory_mb: builtins.float = ...,
        build_environment_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        docker_registry: builtins.str = ...,
        docker_repository: builtins.str = ...,
        entry_point: builtins.str = ...,
        environment_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        https_trigger_security_level: builtins.str = ...,
        https_trigger_url: builtins.str = ...,
        id: builtins.str = ...,
        ingress_settings: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        max_instances: builtins.float = ...,
        min_instances: builtins.float = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        runtime: builtins.str = ...,
        service_account_email: builtins.str = ...,
        source_archive_bucket: builtins.str = ...,
        source_archive_object: builtins.str = ...,
        timeout: builtins.float = ...,
        trigger_http: builtins.bool = ...,
        vpc_connector: builtins.str = ...,
        vpc_connector_egress_settings: builtins.str = ...,
        event_trigger: global___CloudfunctionsFunctionXEventTrigger | None = ...,
        secret_environment_variables: collections.abc.Iterable[global___CloudfunctionsFunctionXSecretEnvironmentVariables] | None = ...,
        secret_volumes: collections.abc.Iterable[global___CloudfunctionsFunctionXSecretVolumes] | None = ...,
        source_repository: global___CloudfunctionsFunctionXSourceRepository | None = ...,
        timeouts: global___CloudfunctionsFunctionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event_trigger", b"event_trigger", "resource_info", b"resource_info", "source_repository", b"source_repository", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_memory_mb", b"available_memory_mb", "build_environment_variables", b"build_environment_variables", "description", b"description", "docker_registry", b"docker_registry", "docker_repository", b"docker_repository", "entry_point", b"entry_point", "environment_variables", b"environment_variables", "event_trigger", b"event_trigger", "https_trigger_security_level", b"https_trigger_security_level", "https_trigger_url", b"https_trigger_url", "id", b"id", "ingress_settings", b"ingress_settings", "kms_key_name", b"kms_key_name", "labels", b"labels", "max_instances", b"max_instances", "min_instances", b"min_instances", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "runtime", b"runtime", "secret_environment_variables", b"secret_environment_variables", "secret_volumes", b"secret_volumes", "service_account_email", b"service_account_email", "source_archive_bucket", b"source_archive_bucket", "source_archive_object", b"source_archive_object", "source_repository", b"source_repository", "timeout", b"timeout", "timeouts", b"timeouts", "trigger_http", b"trigger_http", "vpc_connector", b"vpc_connector", "vpc_connector_egress_settings", b"vpc_connector_egress_settings"]) -> None: ...

global___CloudfunctionsFunction = CloudfunctionsFunction

@typing_extensions.final
class CloudfunctionsFunctionIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudfunctionsFunctionIamBindingXCondition = CloudfunctionsFunctionIamBindingXCondition

@typing_extensions.final
class CloudfunctionsFunctionIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudfunctionsFunctionIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudfunctionsFunctionIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudfunctionsFunctionIamBinding = CloudfunctionsFunctionIamBinding

@typing_extensions.final
class CloudfunctionsFunctionIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudfunctionsFunctionIamMemberXCondition = CloudfunctionsFunctionIamMemberXCondition

@typing_extensions.final
class CloudfunctionsFunctionIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudfunctionsFunctionIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudfunctionsFunctionIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudfunctionsFunctionIamMember = CloudfunctionsFunctionIamMember

@typing_extensions.final
class CloudfunctionsFunctionIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___CloudfunctionsFunctionIamPolicy = CloudfunctionsFunctionIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FirestoreDocumentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___FirestoreDocumentXTimeouts = FirestoreDocumentXTimeouts

@typing_extensions.final
class FirestoreDocument(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    DOCUMENT_ID_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    collection: builtins.str
    create_time: builtins.str
    database: builtins.str
    document_id: builtins.str
    fields: builtins.str
    id: builtins.str
    name: builtins.str
    path: builtins.str
    project: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___FirestoreDocumentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        collection: builtins.str = ...,
        create_time: builtins.str = ...,
        database: builtins.str = ...,
        document_id: builtins.str = ...,
        fields: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        path: builtins.str = ...,
        project: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___FirestoreDocumentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection", b"collection", "create_time", b"create_time", "database", b"database", "document_id", b"document_id", "fields", b"fields", "id", b"id", "name", b"name", "path", b"path", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___FirestoreDocument = FirestoreDocument

@typing_extensions.final
class FirestoreIndexXFields(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARRAY_CONFIG_FIELD_NUMBER: builtins.int
    FIELD_PATH_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    array_config: builtins.str
    field_path: builtins.str
    order: builtins.str
    def __init__(
        self,
        *,
        array_config: builtins.str = ...,
        field_path: builtins.str = ...,
        order: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["array_config", b"array_config", "field_path", b"field_path", "order", b"order"]) -> None: ...

global___FirestoreIndexXFields = FirestoreIndexXFields

@typing_extensions.final
class FirestoreIndexXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___FirestoreIndexXTimeouts = FirestoreIndexXTimeouts

@typing_extensions.final
class FirestoreIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    QUERY_SCOPE_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    collection: builtins.str
    database: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    query_scope: builtins.str
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FirestoreIndexXFields]: ...
    @property
    def timeouts(self) -> global___FirestoreIndexXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        collection: builtins.str = ...,
        database: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        query_scope: builtins.str = ...,
        fields: collections.abc.Iterable[global___FirestoreIndexXFields] | None = ...,
        timeouts: global___FirestoreIndexXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection", b"collection", "database", b"database", "fields", b"fields", "id", b"id", "name", b"name", "project", b"project", "query_scope", b"query_scope", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___FirestoreIndex = FirestoreIndex



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_neptune.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_neptune.proto\x12\x17oak9.tython.aws.neptune\x1a\x13shared/shared.proto\"y\n\x16\x44\x42\x43lusterDBClusterRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x03 \x01(\t\"\xcc\x06\n\tDBCluster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11storage_encrypted\x18\x02 \x01(\x08\x12\x17\n\x0frestore_to_time\x18\x03 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x04 \x01(\t\x12\x12\n\nkms_key_id\x18\x05 \x01(\t\x12I\n\x10\x61ssociated_roles\x18\x06 \x03(\x0b\x32/.oak9.tython.aws.neptune.DBClusterDBClusterRole\x12\x1a\n\x12\x61vailability_zones\x18\x07 \x03(\t\x12\x1b\n\x13snapshot_identifier\x18\x08 \x01(\t\x12\x0c\n\x04port\x18\t \x01(\x05\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\n \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x0b \x01(\t\x12\x18\n\x10iam_auth_enabled\x18\x0c \x01(\x08\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\r \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12\x1f\n\x17preferred_backup_window\x18\x0f \x01(\t\x12\"\n\x1ause_latest_restorable_time\x18\x10 \x01(\x08\x12\x1e\n\x16vpc_security_group_ids\x18\x11 \x03(\t\x12$\n\x1csource_db_cluster_identifier\x18\x12 \x01(\t\x12\'\n\x1f\x64\x62_cluster_parameter_group_name\x18\x13 \x01(\t\x12\x1f\n\x17\x62\x61\x63kup_retention_period\x18\x14 \x01(\x05\x12\x14\n\x0crestore_type\x18\x15 \x01(\t\x12:\n\x04tags\x18\x16 \x03(\x0b\x32,.oak9.tython.aws.neptune.DBCluster.TagsEntry\x12&\n\x1e\x65nable_cloudwatch_logs_exports\x18\x17 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x02\n\x07Neptune\x12\x36\n\ndb_cluster\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.neptune.DBCluster\x12T\n\x1a\x64\x62_cluster_parameter_group\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.neptune.DBClusterParameterGroup\x12\x38\n\x0b\x64\x62_instance\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.neptune.DBInstance\x12\x45\n\x12\x64\x62_parameter_group\x18\x04 \x03(\x0b\x32).oak9.tython.aws.neptune.DBParameterGroup\x12?\n\x0f\x64\x62_subnet_group\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.neptune.DBSubnetGroup\"\x85\x03\n\x17\x44\x42\x43lusterParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12T\n\nparameters\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.neptune.DBClusterParameterGroup.ParametersEntry\x12\x0e\n\x06\x66\x61mily\x18\x04 \x01(\t\x12H\n\x04tags\x18\x05 \x03(\x0b\x32:.oak9.tython.aws.neptune.DBClusterParameterGroup.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x03\n\nDBInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x64\x62_parameter_group_name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x62_instance_class\x18\x03 \x01(\t\x12#\n\x1b\x61llow_major_version_upgrade\x18\x04 \x01(\x08\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x05 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x07 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x08 \x01(\x08\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\t \x01(\t\x12\x1e\n\x16\x64\x62_instance_identifier\x18\n \x01(\t\x12\x1e\n\x16\x64\x62_snapshot_identifier\x18\x0b \x01(\t\x12;\n\x04tags\x18\x0c \x03(\x0b\x32-.oak9.tython.aws.neptune.DBInstance.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x02\n\x10\x44\x42ParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12M\n\nparameters\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.neptune.DBParameterGroup.ParametersEntry\x12\x0e\n\x06\x66\x61mily\x18\x04 \x01(\t\x12\x41\n\x04tags\x18\x05 \x03(\x0b\x32\x33.oak9.tython.aws.neptune.DBParameterGroup.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x02\n\rDBSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x02 \x01(\t\x12#\n\x1b\x64\x62_subnet_group_description\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12>\n\x04tags\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.neptune.DBSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_neptune_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBCLUSTER_TAGSENTRY._options = None
  _DBCLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBINSTANCE_TAGSENTRY._options = None
  _DBINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _DBPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBPARAMETERGROUP_TAGSENTRY._options = None
  _DBPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSUBNETGROUP_TAGSENTRY._options = None
  _DBSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERDBCLUSTERROLE._serialized_start=71
  _DBCLUSTERDBCLUSTERROLE._serialized_end=192
  _DBCLUSTER._serialized_start=195
  _DBCLUSTER._serialized_end=1039
  _DBCLUSTER_TAGSENTRY._serialized_start=996
  _DBCLUSTER_TAGSENTRY._serialized_end=1039
  _NEPTUNE._serialized_start=1042
  _NEPTUNE._serialized_end=1387
  _DBCLUSTERPARAMETERGROUP._serialized_start=1390
  _DBCLUSTERPARAMETERGROUP._serialized_end=1779
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_start=1685
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_end=1734
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_start=996
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_end=1039
  _DBINSTANCE._serialized_start=1782
  _DBINSTANCE._serialized_end=2280
  _DBINSTANCE_TAGSENTRY._serialized_start=996
  _DBINSTANCE_TAGSENTRY._serialized_end=1039
  _DBPARAMETERGROUP._serialized_start=2283
  _DBPARAMETERGROUP._serialized_end=2651
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_start=1685
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_end=1734
  _DBPARAMETERGROUP_TAGSENTRY._serialized_start=996
  _DBPARAMETERGROUP_TAGSENTRY._serialized_end=1039
  _DBSUBNETGROUP._serialized_start=2654
  _DBSUBNETGROUP._serialized_end=2922
  _DBSUBNETGROUP_TAGSENTRY._serialized_start=996
  _DBSUBNETGROUP_TAGSENTRY._serialized_end=1039
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class WorkspaceWorkspaceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPUTE_TYPE_NAME_FIELD_NUMBER: builtins.int
    ROOT_VOLUME_SIZE_GIB_FIELD_NUMBER: builtins.int
    RUNNING_MODE_FIELD_NUMBER: builtins.int
    RUNNING_MODE_AUTO_STOP_TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    USER_VOLUME_SIZE_GIB_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    compute_type_name: builtins.str
    root_volume_size_gib: builtins.int
    running_mode: builtins.str
    running_mode_auto_stop_timeout_in_minutes: builtins.int
    user_volume_size_gib: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        compute_type_name: builtins.str = ...,
        root_volume_size_gib: builtins.int = ...,
        running_mode: builtins.str = ...,
        running_mode_auto_stop_timeout_in_minutes: builtins.int = ...,
        user_volume_size_gib: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_type_name", b"compute_type_name", "resource_info", b"resource_info", "root_volume_size_gib", b"root_volume_size_gib", "running_mode", b"running_mode", "running_mode_auto_stop_timeout_in_minutes", b"running_mode_auto_stop_timeout_in_minutes", "user_volume_size_gib", b"user_volume_size_gib"]) -> None: ...

global___WorkspaceWorkspaceProperties = WorkspaceWorkspaceProperties

@typing_extensions.final
class Workspace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUNDLE_ID_FIELD_NUMBER: builtins.int
    DIRECTORY_ID_FIELD_NUMBER: builtins.int
    ROOT_VOLUME_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    USER_VOLUME_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    VOLUME_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    WORKSPACE_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bundle_id: builtins.str
    directory_id: builtins.str
    root_volume_encryption_enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    user_name: builtins.str
    user_volume_encryption_enabled: builtins.bool
    volume_encryption_key: builtins.str
    @property
    def workspace_properties(self) -> global___WorkspaceWorkspaceProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bundle_id: builtins.str = ...,
        directory_id: builtins.str = ...,
        root_volume_encryption_enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        user_name: builtins.str = ...,
        user_volume_encryption_enabled: builtins.bool = ...,
        volume_encryption_key: builtins.str = ...,
        workspace_properties: global___WorkspaceWorkspaceProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "workspace_properties", b"workspace_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bundle_id", b"bundle_id", "directory_id", b"directory_id", "resource_info", b"resource_info", "root_volume_encryption_enabled", b"root_volume_encryption_enabled", "tags", b"tags", "user_name", b"user_name", "user_volume_encryption_enabled", b"user_volume_encryption_enabled", "volume_encryption_key", b"volume_encryption_key", "workspace_properties", b"workspace_properties"]) -> None: ...

global___Workspace = Workspace

@typing_extensions.final
class WorkSpaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_FIELD_NUMBER: builtins.int
    @property
    def workspace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Workspace]: ...
    def __init__(
        self,
        *,
        workspace: collections.abc.Iterable[global___Workspace] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace", b"workspace"]) -> None: ...

global___WorkSpaces = WorkSpaces



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Account(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cloud_watch_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_role_arn", b"cloud_watch_role_arn", "resource_info", b"resource_info"]) -> None: ...

global___Account = Account

@typing_extensions.final
class ApiGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    AUTHORIZER_FIELD_NUMBER: builtins.int
    BASE_PATH_MAPPING_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    GATEWAY_RESPONSE_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    REQUEST_VALIDATOR_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    REST_API_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    USAGE_PLAN_FIELD_NUMBER: builtins.int
    USAGE_PLAN_KEY_FIELD_NUMBER: builtins.int
    @property
    def account(self) -> global___Account: ...
    @property
    def api_key(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiKey]: ...
    @property
    def authorizer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Authorizer]: ...
    @property
    def base_path_mapping(self) -> global___BasePathMapping: ...
    @property
    def deployment(self) -> global___Deployment: ...
    @property
    def domain_name(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainName]: ...
    @property
    def gateway_response(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GatewayResponse]: ...
    @property
    def method(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Method]: ...
    @property
    def request_validator(self) -> global___RequestValidator: ...
    @property
    def resource(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Resource]: ...
    @property
    def rest_api(self) -> global___RestApi: ...
    @property
    def stage(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stage]: ...
    @property
    def usage_plan(self) -> global___UsagePlan: ...
    @property
    def usage_plan_key(self) -> global___UsagePlanKey: ...
    def __init__(
        self,
        *,
        account: global___Account | None = ...,
        api_key: collections.abc.Iterable[global___ApiKey] | None = ...,
        authorizer: collections.abc.Iterable[global___Authorizer] | None = ...,
        base_path_mapping: global___BasePathMapping | None = ...,
        deployment: global___Deployment | None = ...,
        domain_name: collections.abc.Iterable[global___DomainName] | None = ...,
        gateway_response: collections.abc.Iterable[global___GatewayResponse] | None = ...,
        method: collections.abc.Iterable[global___Method] | None = ...,
        request_validator: global___RequestValidator | None = ...,
        resource: collections.abc.Iterable[global___Resource] | None = ...,
        rest_api: global___RestApi | None = ...,
        stage: collections.abc.Iterable[global___Stage] | None = ...,
        usage_plan: global___UsagePlan | None = ...,
        usage_plan_key: global___UsagePlanKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account", b"account", "base_path_mapping", b"base_path_mapping", "deployment", b"deployment", "request_validator", b"request_validator", "rest_api", b"rest_api", "usage_plan", b"usage_plan", "usage_plan_key", b"usage_plan_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account", b"account", "api_key", b"api_key", "authorizer", b"authorizer", "base_path_mapping", b"base_path_mapping", "deployment", b"deployment", "domain_name", b"domain_name", "gateway_response", b"gateway_response", "method", b"method", "request_validator", b"request_validator", "resource", b"resource", "rest_api", b"rest_api", "stage", b"stage", "usage_plan", b"usage_plan", "usage_plan_key", b"usage_plan_key"]) -> None: ...

global___ApiGateway = ApiGateway

@typing_extensions.final
class ApiKeyStageKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    rest_api_id: builtins.str
    stage_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rest_api_id: builtins.str = ...,
        stage_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "stage_name", b"stage_name"]) -> None: ...

global___ApiKeyStageKey = ApiKeyStageKey

@typing_extensions.final
class ApiKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    GENERATE_DISTINCT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STAGE_KEYS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    customer_id: builtins.str
    description: builtins.str
    enabled: builtins.bool
    generate_distinct_id: builtins.bool
    name: builtins.str
    @property
    def stage_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiKeyStageKey]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        customer_id: builtins.str = ...,
        description: builtins.str = ...,
        enabled: builtins.bool = ...,
        generate_distinct_id: builtins.bool = ...,
        name: builtins.str = ...,
        stage_keys: collections.abc.Iterable[global___ApiKeyStageKey] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_id", b"customer_id", "description", b"description", "enabled", b"enabled", "generate_distinct_id", b"generate_distinct_id", "name", b"name", "resource_info", b"resource_info", "stage_keys", b"stage_keys", "tags", b"tags", "value", b"value"]) -> None: ...

global___ApiKey = ApiKey

@typing_extensions.final
class Authorizer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTH_TYPE_FIELD_NUMBER: builtins.int
    AUTHORIZER_CREDENTIALS_FIELD_NUMBER: builtins.int
    AUTHORIZER_RESULT_TTL_IN_SECONDS_FIELD_NUMBER: builtins.int
    AUTHORIZER_URI_FIELD_NUMBER: builtins.int
    IDENTITY_SOURCE_FIELD_NUMBER: builtins.int
    IDENTITY_VALIDATION_EXPRESSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_ARNS_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    auth_type: builtins.str
    authorizer_credentials: builtins.str
    authorizer_result_ttl_in_seconds: builtins.int
    authorizer_uri: builtins.str
    identity_source: builtins.str
    identity_validation_expression: builtins.str
    name: builtins.str
    @property
    def provider_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    rest_api_id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auth_type: builtins.str = ...,
        authorizer_credentials: builtins.str = ...,
        authorizer_result_ttl_in_seconds: builtins.int = ...,
        authorizer_uri: builtins.str = ...,
        identity_source: builtins.str = ...,
        identity_validation_expression: builtins.str = ...,
        name: builtins.str = ...,
        provider_arns: collections.abc.Iterable[builtins.str] | None = ...,
        rest_api_id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "authorizer_credentials", b"authorizer_credentials", "authorizer_result_ttl_in_seconds", b"authorizer_result_ttl_in_seconds", "authorizer_uri", b"authorizer_uri", "identity_source", b"identity_source", "identity_validation_expression", b"identity_validation_expression", "name", b"name", "provider_arns", b"provider_arns", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "type", b"type"]) -> None: ...

global___Authorizer = Authorizer

@typing_extensions.final
class BasePathMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BASE_PATH_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    base_path: builtins.str
    domain_name: builtins.str
    rest_api_id: builtins.str
    stage: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        base_path: builtins.str = ...,
        domain_name: builtins.str = ...,
        rest_api_id: builtins.str = ...,
        stage: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_path", b"base_path", "domain_name", b"domain_name", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "stage", b"stage"]) -> None: ...

global___BasePathMapping = BasePathMapping

@typing_extensions.final
class ClientCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ClientCertificate = ClientCertificate

@typing_extensions.final
class DeploymentDeploymentCanarySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StageVariableOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PERCENT_TRAFFIC_FIELD_NUMBER: builtins.int
    STAGE_VARIABLE_OVERRIDES_FIELD_NUMBER: builtins.int
    USE_STAGE_CACHE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    percent_traffic: builtins.float
    @property
    def stage_variable_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    use_stage_cache: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        percent_traffic: builtins.float = ...,
        stage_variable_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        use_stage_cache: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["percent_traffic", b"percent_traffic", "resource_info", b"resource_info", "stage_variable_overrides", b"stage_variable_overrides", "use_stage_cache", b"use_stage_cache"]) -> None: ...

global___DeploymentDeploymentCanarySettings = DeploymentDeploymentCanarySettings

@typing_extensions.final
class DeploymentAccessLogSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_arn: builtins.str
    format: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_arn: builtins.str = ...,
        format: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "format", b"format", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentAccessLogSetting = DeploymentAccessLogSetting

@typing_extensions.final
class DeploymentCanarySetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StageVariableOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PERCENT_TRAFFIC_FIELD_NUMBER: builtins.int
    STAGE_VARIABLE_OVERRIDES_FIELD_NUMBER: builtins.int
    USE_STAGE_CACHE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    percent_traffic: builtins.float
    @property
    def stage_variable_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    use_stage_cache: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        percent_traffic: builtins.float = ...,
        stage_variable_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        use_stage_cache: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["percent_traffic", b"percent_traffic", "resource_info", b"resource_info", "stage_variable_overrides", b"stage_variable_overrides", "use_stage_cache", b"use_stage_cache"]) -> None: ...

global___DeploymentCanarySetting = DeploymentCanarySetting

@typing_extensions.final
class DeploymentMethodSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_DATA_ENCRYPTED_FIELD_NUMBER: builtins.int
    CACHE_TTL_IN_SECONDS_FIELD_NUMBER: builtins.int
    CACHING_ENABLED_FIELD_NUMBER: builtins.int
    DATA_TRACE_ENABLED_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    METRICS_ENABLED_FIELD_NUMBER: builtins.int
    RESOURCE_PATH_FIELD_NUMBER: builtins.int
    THROTTLING_BURST_LIMIT_FIELD_NUMBER: builtins.int
    THROTTLING_RATE_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_data_encrypted: builtins.bool
    cache_ttl_in_seconds: builtins.int
    caching_enabled: builtins.bool
    data_trace_enabled: builtins.bool
    http_method: builtins.str
    logging_level: builtins.str
    metrics_enabled: builtins.bool
    resource_path: builtins.str
    throttling_burst_limit: builtins.int
    throttling_rate_limit: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_data_encrypted: builtins.bool = ...,
        cache_ttl_in_seconds: builtins.int = ...,
        caching_enabled: builtins.bool = ...,
        data_trace_enabled: builtins.bool = ...,
        http_method: builtins.str = ...,
        logging_level: builtins.str = ...,
        metrics_enabled: builtins.bool = ...,
        resource_path: builtins.str = ...,
        throttling_burst_limit: builtins.int = ...,
        throttling_rate_limit: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_data_encrypted", b"cache_data_encrypted", "cache_ttl_in_seconds", b"cache_ttl_in_seconds", "caching_enabled", b"caching_enabled", "data_trace_enabled", b"data_trace_enabled", "http_method", b"http_method", "logging_level", b"logging_level", "metrics_enabled", b"metrics_enabled", "resource_info", b"resource_info", "resource_path", b"resource_path", "throttling_burst_limit", b"throttling_burst_limit", "throttling_rate_limit", b"throttling_rate_limit"]) -> None: ...

global___DeploymentMethodSetting = DeploymentMethodSetting

@typing_extensions.final
class DeploymentStageDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCESS_LOG_SETTING_FIELD_NUMBER: builtins.int
    CACHE_CLUSTER_ENABLED_FIELD_NUMBER: builtins.int
    CACHE_CLUSTER_SIZE_FIELD_NUMBER: builtins.int
    CACHE_DATA_ENCRYPTED_FIELD_NUMBER: builtins.int
    CACHE_TTL_IN_SECONDS_FIELD_NUMBER: builtins.int
    CACHING_ENABLED_FIELD_NUMBER: builtins.int
    CANARY_SETTING_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    DATA_TRACE_ENABLED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCUMENTATION_VERSION_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    METHOD_SETTINGS_FIELD_NUMBER: builtins.int
    METRICS_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    THROTTLING_BURST_LIMIT_FIELD_NUMBER: builtins.int
    THROTTLING_RATE_LIMIT_FIELD_NUMBER: builtins.int
    TRACING_ENABLED_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def access_log_setting(self) -> global___DeploymentAccessLogSetting: ...
    cache_cluster_enabled: builtins.bool
    cache_cluster_size: builtins.str
    cache_data_encrypted: builtins.bool
    cache_ttl_in_seconds: builtins.int
    caching_enabled: builtins.bool
    @property
    def canary_setting(self) -> global___DeploymentCanarySetting: ...
    client_certificate_id: builtins.str
    data_trace_enabled: builtins.bool
    description: builtins.str
    documentation_version: builtins.str
    logging_level: builtins.str
    @property
    def method_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentMethodSetting]: ...
    metrics_enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    throttling_burst_limit: builtins.int
    throttling_rate_limit: builtins.float
    tracing_enabled: builtins.bool
    @property
    def variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        access_log_setting: global___DeploymentAccessLogSetting | None = ...,
        cache_cluster_enabled: builtins.bool = ...,
        cache_cluster_size: builtins.str = ...,
        cache_data_encrypted: builtins.bool = ...,
        cache_ttl_in_seconds: builtins.int = ...,
        caching_enabled: builtins.bool = ...,
        canary_setting: global___DeploymentCanarySetting | None = ...,
        client_certificate_id: builtins.str = ...,
        data_trace_enabled: builtins.bool = ...,
        description: builtins.str = ...,
        documentation_version: builtins.str = ...,
        logging_level: builtins.str = ...,
        method_settings: collections.abc.Iterable[global___DeploymentMethodSetting] | None = ...,
        metrics_enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        throttling_burst_limit: builtins.int = ...,
        throttling_rate_limit: builtins.float = ...,
        tracing_enabled: builtins.bool = ...,
        variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_log_setting", b"access_log_setting", "canary_setting", b"canary_setting", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_log_setting", b"access_log_setting", "cache_cluster_enabled", b"cache_cluster_enabled", "cache_cluster_size", b"cache_cluster_size", "cache_data_encrypted", b"cache_data_encrypted", "cache_ttl_in_seconds", b"cache_ttl_in_seconds", "caching_enabled", b"caching_enabled", "canary_setting", b"canary_setting", "client_certificate_id", b"client_certificate_id", "data_trace_enabled", b"data_trace_enabled", "description", b"description", "documentation_version", b"documentation_version", "logging_level", b"logging_level", "method_settings", b"method_settings", "metrics_enabled", b"metrics_enabled", "resource_info", b"resource_info", "tags", b"tags", "throttling_burst_limit", b"throttling_burst_limit", "throttling_rate_limit", b"throttling_rate_limit", "tracing_enabled", b"tracing_enabled", "variables", b"variables"]) -> None: ...

global___DeploymentStageDescription = DeploymentStageDescription

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CANARY_SETTINGS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    STAGE_DESCRIPTION_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def deployment_canary_settings(self) -> global___DeploymentDeploymentCanarySettings: ...
    description: builtins.str
    rest_api_id: builtins.str
    @property
    def stage_description(self) -> global___DeploymentStageDescription: ...
    stage_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_canary_settings: global___DeploymentDeploymentCanarySettings | None = ...,
        description: builtins.str = ...,
        rest_api_id: builtins.str = ...,
        stage_description: global___DeploymentStageDescription | None = ...,
        stage_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_canary_settings", b"deployment_canary_settings", "resource_info", b"resource_info", "stage_description", b"stage_description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_canary_settings", b"deployment_canary_settings", "description", b"description", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "stage_description", b"stage_description", "stage_name", b"stage_name"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DocumentationPartLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    method: builtins.str
    name: builtins.str
    path: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        method: builtins.str = ...,
        name: builtins.str = ...,
        path: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["method", b"method", "name", b"name", "path", b"path", "resource_info", b"resource_info", "status_code", b"status_code"]) -> None: ...

global___DocumentationPartLocation = DocumentationPartLocation

@typing_extensions.final
class DocumentationPart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def location(self) -> global___DocumentationPartLocation: ...
    properties: builtins.str
    rest_api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: global___DocumentationPartLocation | None = ...,
        properties: builtins.str = ...,
        rest_api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "properties", b"properties", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id"]) -> None: ...

global___DocumentationPart = DocumentationPart

@typing_extensions.final
class DocumentationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCUMENTATION_VERSION_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    documentation_version: builtins.str
    rest_api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        documentation_version: builtins.str = ...,
        rest_api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "documentation_version", b"documentation_version", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id"]) -> None: ...

global___DocumentationVersion = DocumentationVersion

@typing_extensions.final
class DomainNameEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "types", b"types"]) -> None: ...

global___DomainNameEndpointConfiguration = DomainNameEndpointConfiguration

@typing_extensions.final
class DomainNameMutualTlsAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRUSTSTORE_URI_FIELD_NUMBER: builtins.int
    TRUSTSTORE_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    truststore_uri: builtins.str
    truststore_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        truststore_uri: builtins.str = ...,
        truststore_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "truststore_uri", b"truststore_uri", "truststore_version", b"truststore_version"]) -> None: ...

global___DomainNameMutualTlsAuthentication = DomainNameMutualTlsAuthentication

@typing_extensions.final
class DomainName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIGURATION_FIELD_NUMBER: builtins.int
    MUTUAL_TLS_AUTHENTICATION_FIELD_NUMBER: builtins.int
    CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    REGIONAL_CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    SECURITY_POLICY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    domain_name: builtins.str
    @property
    def endpoint_configuration(self) -> global___DomainNameEndpointConfiguration: ...
    @property
    def mutual_tls_authentication(self) -> global___DomainNameMutualTlsAuthentication: ...
    certificate_arn: builtins.str
    regional_certificate_arn: builtins.str
    security_policy: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        domain_name: builtins.str = ...,
        endpoint_configuration: global___DomainNameEndpointConfiguration | None = ...,
        mutual_tls_authentication: global___DomainNameMutualTlsAuthentication | None = ...,
        certificate_arn: builtins.str = ...,
        regional_certificate_arn: builtins.str = ...,
        security_policy: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint_configuration", b"endpoint_configuration", "mutual_tls_authentication", b"mutual_tls_authentication", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_arn", b"certificate_arn", "domain_name", b"domain_name", "endpoint_configuration", b"endpoint_configuration", "mutual_tls_authentication", b"mutual_tls_authentication", "regional_certificate_arn", b"regional_certificate_arn", "resource_info", b"resource_info", "security_policy", b"security_policy", "tags", b"tags"]) -> None: ...

global___DomainName = DomainName

@typing_extensions.final
class GatewayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    RESPONSE_TEMPLATES_FIELD_NUMBER: builtins.int
    RESPONSE_TYPE_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def response_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    response_type: builtins.str
    rest_api_id: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        response_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        response_type: builtins.str = ...,
        rest_api_id: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "response_parameters", b"response_parameters", "response_templates", b"response_templates", "response_type", b"response_type", "rest_api_id", b"rest_api_id", "status_code", b"status_code"]) -> None: ...

global___GatewayResponse = GatewayResponse

@typing_extensions.final
class MethodIntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_HANDLING_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    RESPONSE_TEMPLATES_FIELD_NUMBER: builtins.int
    SELECTION_PATTERN_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_handling: builtins.str
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def response_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    selection_pattern: builtins.str
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_handling: builtins.str = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        response_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        selection_pattern: builtins.str = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_handling", b"content_handling", "resource_info", b"resource_info", "response_parameters", b"response_parameters", "response_templates", b"response_templates", "selection_pattern", b"selection_pattern", "status_code", b"status_code"]) -> None: ...

global___MethodIntegrationResponse = MethodIntegrationResponse

@typing_extensions.final
class MethodIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_KEY_PARAMETERS_FIELD_NUMBER: builtins.int
    CACHE_NAMESPACE_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_HANDLING_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    INTEGRATION_HTTP_METHOD_FIELD_NUMBER: builtins.int
    INTEGRATION_RESPONSES_FIELD_NUMBER: builtins.int
    PASSTHROUGH_BEHAVIOR_FIELD_NUMBER: builtins.int
    REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    REQUEST_TEMPLATES_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_MILLIS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cache_key_parameters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cache_namespace: builtins.str
    connection_id: builtins.str
    connection_type: builtins.str
    content_handling: builtins.str
    credentials: builtins.str
    integration_http_method: builtins.str
    @property
    def integration_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MethodIntegrationResponse]: ...
    passthrough_behavior: builtins.str
    @property
    def request_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def request_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    timeout_in_millis: builtins.int
    uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_key_parameters: collections.abc.Iterable[builtins.str] | None = ...,
        cache_namespace: builtins.str = ...,
        connection_id: builtins.str = ...,
        connection_type: builtins.str = ...,
        content_handling: builtins.str = ...,
        credentials: builtins.str = ...,
        integration_http_method: builtins.str = ...,
        integration_responses: collections.abc.Iterable[global___MethodIntegrationResponse] | None = ...,
        passthrough_behavior: builtins.str = ...,
        request_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        request_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timeout_in_millis: builtins.int = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_key_parameters", b"cache_key_parameters", "cache_namespace", b"cache_namespace", "connection_id", b"connection_id", "connection_type", b"connection_type", "content_handling", b"content_handling", "credentials", b"credentials", "integration_http_method", b"integration_http_method", "integration_responses", b"integration_responses", "passthrough_behavior", b"passthrough_behavior", "request_parameters", b"request_parameters", "request_templates", b"request_templates", "resource_info", b"resource_info", "timeout_in_millis", b"timeout_in_millis", "uri", b"uri"]) -> None: ...

global___MethodIntegration = MethodIntegration

@typing_extensions.final
class MethodMethodResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseModelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_MODELS_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def response_models(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    status_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_models: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "response_models", b"response_models", "response_parameters", b"response_parameters", "status_code", b"status_code"]) -> None: ...

global___MethodMethodResponse = MethodMethodResponse

@typing_extensions.final
class Method(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestModelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_KEY_REQUIRED_FIELD_NUMBER: builtins.int
    AUTHORIZATION_SCOPES_FIELD_NUMBER: builtins.int
    AUTHORIZATION_TYPE_FIELD_NUMBER: builtins.int
    AUTHORIZER_ID_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    INTEGRATION_FIELD_NUMBER: builtins.int
    METHOD_RESPONSES_FIELD_NUMBER: builtins.int
    OPERATION_NAME_FIELD_NUMBER: builtins.int
    REQUEST_MODELS_FIELD_NUMBER: builtins.int
    REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    REQUEST_VALIDATOR_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    DEPENDS_ON_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_key_required: builtins.bool
    @property
    def authorization_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    authorization_type: builtins.str
    authorizer_id: builtins.str
    http_method: builtins.str
    @property
    def integration(self) -> global___MethodIntegration: ...
    @property
    def method_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MethodMethodResponse]: ...
    operation_name: builtins.str
    @property
    def request_models(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def request_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    request_validator_id: builtins.str
    resource_id: builtins.str
    rest_api_id: builtins.str
    depends_on: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_key_required: builtins.bool = ...,
        authorization_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        authorization_type: builtins.str = ...,
        authorizer_id: builtins.str = ...,
        http_method: builtins.str = ...,
        integration: global___MethodIntegration | None = ...,
        method_responses: collections.abc.Iterable[global___MethodMethodResponse] | None = ...,
        operation_name: builtins.str = ...,
        request_models: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        request_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        request_validator_id: builtins.str = ...,
        resource_id: builtins.str = ...,
        rest_api_id: builtins.str = ...,
        depends_on: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration", b"integration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_required", b"api_key_required", "authorization_scopes", b"authorization_scopes", "authorization_type", b"authorization_type", "authorizer_id", b"authorizer_id", "depends_on", b"depends_on", "http_method", b"http_method", "integration", b"integration", "method_responses", b"method_responses", "operation_name", b"operation_name", "request_models", b"request_models", "request_parameters", b"request_parameters", "request_validator_id", b"request_validator_id", "resource_id", b"resource_id", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id"]) -> None: ...

global___Method = Method

@typing_extensions.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SchemaEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_type: builtins.str
    description: builtins.str
    name: builtins.str
    rest_api_id: builtins.str
    @property
    def schema(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_type: builtins.str = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        rest_api_id: builtins.str = ...,
        schema: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "description", b"description", "name", b"name", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "schema", b"schema"]) -> None: ...

global___Model = Model

@typing_extensions.final
class RequestValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    VALIDATE_REQUEST_BODY_FIELD_NUMBER: builtins.int
    VALIDATE_REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    rest_api_id: builtins.str
    validate_request_body: builtins.bool
    validate_request_parameters: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rest_api_id: builtins.str = ...,
        validate_request_body: builtins.bool = ...,
        validate_request_parameters: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "validate_request_body", b"validate_request_body", "validate_request_parameters", b"validate_request_parameters"]) -> None: ...

global___RequestValidator = RequestValidator

@typing_extensions.final
class Resource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARENT_ID_FIELD_NUMBER: builtins.int
    PATH_PART_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    parent_id: builtins.str
    path_part: builtins.str
    rest_api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parent_id: builtins.str = ...,
        path_part: builtins.str = ...,
        rest_api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parent_id", b"parent_id", "path_part", b"path_part", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id"]) -> None: ...

global___Resource = Resource

@typing_extensions.final
class RestApiS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket: builtins.str
    e_tag: builtins.str
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket: builtins.str = ...,
        e_tag: builtins.str = ...,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "e_tag", b"e_tag", "key", b"key", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___RestApiS3Location = RestApiS3Location

@typing_extensions.final
class RestApiEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPES_FIELD_NUMBER: builtins.int
    VPC_ENDPOINT_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def vpc_endpoint_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        types: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_endpoint_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "types", b"types", "vpc_endpoint_ids", b"vpc_endpoint_ids"]) -> None: ...

global___RestApiEndpointConfiguration = RestApiEndpointConfiguration

@typing_extensions.final
class RestApi(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BodyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_KEY_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    BINARY_MEDIA_TYPES_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    BODY_S3_LOCATION_FIELD_NUMBER: builtins.int
    CLONE_FROM_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIGURATION_FIELD_NUMBER: builtins.int
    FAIL_ON_WARNINGS_FIELD_NUMBER: builtins.int
    MINIMUM_COMPRESSION_SIZE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DISABLE_EXECUTE_API_ENDPOINT_FIELD_NUMBER: builtins.int
    API_KEY_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_key_source_type: builtins.str
    @property
    def binary_media_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def body(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def body_s3_location(self) -> global___RestApiS3Location: ...
    clone_from: builtins.str
    description: builtins.str
    @property
    def endpoint_configuration(self) -> global___RestApiEndpointConfiguration: ...
    fail_on_warnings: builtins.bool
    minimum_compression_size: builtins.int
    name: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    policy: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    disable_execute_api_endpoint: builtins.str
    api_key_source: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_key_source_type: builtins.str = ...,
        binary_media_types: collections.abc.Iterable[builtins.str] | None = ...,
        body: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        body_s3_location: global___RestApiS3Location | None = ...,
        clone_from: builtins.str = ...,
        description: builtins.str = ...,
        endpoint_configuration: global___RestApiEndpointConfiguration | None = ...,
        fail_on_warnings: builtins.bool = ...,
        minimum_compression_size: builtins.int = ...,
        name: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        policy: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        disable_execute_api_endpoint: builtins.str = ...,
        api_key_source: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body_s3_location", b"body_s3_location", "endpoint_configuration", b"endpoint_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_source", b"api_key_source", "api_key_source_type", b"api_key_source_type", "binary_media_types", b"binary_media_types", "body", b"body", "body_s3_location", b"body_s3_location", "clone_from", b"clone_from", "description", b"description", "disable_execute_api_endpoint", b"disable_execute_api_endpoint", "endpoint_configuration", b"endpoint_configuration", "fail_on_warnings", b"fail_on_warnings", "minimum_compression_size", b"minimum_compression_size", "name", b"name", "parameters", b"parameters", "policy", b"policy", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___RestApi = RestApi

@typing_extensions.final
class StageAccessLogSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_arn: builtins.str
    format: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_arn: builtins.str = ...,
        format: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "format", b"format", "resource_info", b"resource_info"]) -> None: ...

global___StageAccessLogSetting = StageAccessLogSetting

@typing_extensions.final
class StageCanarySetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StageVariableOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    PERCENT_TRAFFIC_FIELD_NUMBER: builtins.int
    STAGE_VARIABLE_OVERRIDES_FIELD_NUMBER: builtins.int
    USE_STAGE_CACHE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_id: builtins.str
    percent_traffic: builtins.float
    @property
    def stage_variable_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    use_stage_cache: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_id: builtins.str = ...,
        percent_traffic: builtins.float = ...,
        stage_variable_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        use_stage_cache: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "percent_traffic", b"percent_traffic", "resource_info", b"resource_info", "stage_variable_overrides", b"stage_variable_overrides", "use_stage_cache", b"use_stage_cache"]) -> None: ...

global___StageCanarySetting = StageCanarySetting

@typing_extensions.final
class StageMethodSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_DATA_ENCRYPTED_FIELD_NUMBER: builtins.int
    CACHE_TTL_IN_SECONDS_FIELD_NUMBER: builtins.int
    CACHING_ENABLED_FIELD_NUMBER: builtins.int
    DATA_TRACE_ENABLED_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    METRICS_ENABLED_FIELD_NUMBER: builtins.int
    RESOURCE_PATH_FIELD_NUMBER: builtins.int
    THROTTLING_BURST_LIMIT_FIELD_NUMBER: builtins.int
    THROTTLING_RATE_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_data_encrypted: builtins.bool
    cache_ttl_in_seconds: builtins.int
    caching_enabled: builtins.bool
    data_trace_enabled: builtins.bool
    http_method: builtins.str
    logging_level: builtins.str
    metrics_enabled: builtins.bool
    resource_path: builtins.str
    throttling_burst_limit: builtins.int
    throttling_rate_limit: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_data_encrypted: builtins.bool = ...,
        cache_ttl_in_seconds: builtins.int = ...,
        caching_enabled: builtins.bool = ...,
        data_trace_enabled: builtins.bool = ...,
        http_method: builtins.str = ...,
        logging_level: builtins.str = ...,
        metrics_enabled: builtins.bool = ...,
        resource_path: builtins.str = ...,
        throttling_burst_limit: builtins.int = ...,
        throttling_rate_limit: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_data_encrypted", b"cache_data_encrypted", "cache_ttl_in_seconds", b"cache_ttl_in_seconds", "caching_enabled", b"caching_enabled", "data_trace_enabled", b"data_trace_enabled", "http_method", b"http_method", "logging_level", b"logging_level", "metrics_enabled", b"metrics_enabled", "resource_info", b"resource_info", "resource_path", b"resource_path", "throttling_burst_limit", b"throttling_burst_limit", "throttling_rate_limit", b"throttling_rate_limit"]) -> None: ...

global___StageMethodSetting = StageMethodSetting

@typing_extensions.final
class Stage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCESS_LOG_SETTING_FIELD_NUMBER: builtins.int
    CACHE_CLUSTER_ENABLED_FIELD_NUMBER: builtins.int
    CACHE_CLUSTER_SIZE_FIELD_NUMBER: builtins.int
    CANARY_SETTING_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCUMENTATION_VERSION_FIELD_NUMBER: builtins.int
    METHOD_SETTINGS_FIELD_NUMBER: builtins.int
    REST_API_ID_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TRACING_ENABLED_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def access_log_setting(self) -> global___StageAccessLogSetting: ...
    cache_cluster_enabled: builtins.bool
    cache_cluster_size: builtins.str
    @property
    def canary_setting(self) -> global___StageCanarySetting: ...
    client_certificate_id: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    documentation_version: builtins.str
    @property
    def method_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StageMethodSetting]: ...
    rest_api_id: builtins.str
    stage_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    tracing_enabled: builtins.bool
    @property
    def variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        access_log_setting: global___StageAccessLogSetting | None = ...,
        cache_cluster_enabled: builtins.bool = ...,
        cache_cluster_size: builtins.str = ...,
        canary_setting: global___StageCanarySetting | None = ...,
        client_certificate_id: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        documentation_version: builtins.str = ...,
        method_settings: collections.abc.Iterable[global___StageMethodSetting] | None = ...,
        rest_api_id: builtins.str = ...,
        stage_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tracing_enabled: builtins.bool = ...,
        variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_log_setting", b"access_log_setting", "canary_setting", b"canary_setting", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_log_setting", b"access_log_setting", "cache_cluster_enabled", b"cache_cluster_enabled", "cache_cluster_size", b"cache_cluster_size", "canary_setting", b"canary_setting", "client_certificate_id", b"client_certificate_id", "deployment_id", b"deployment_id", "description", b"description", "documentation_version", b"documentation_version", "method_settings", b"method_settings", "resource_info", b"resource_info", "rest_api_id", b"rest_api_id", "stage_name", b"stage_name", "tags", b"tags", "tracing_enabled", b"tracing_enabled", "variables", b"variables"]) -> None: ...

global___Stage = Stage

@typing_extensions.final
class UsagePlanApiStage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ThrottleEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    THROTTLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    api_id: builtins.str
    stage: builtins.str
    @property
    def throttle(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_id: builtins.str = ...,
        stage: builtins.str = ...,
        throttle: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "resource_info", b"resource_info", "stage", b"stage", "throttle", b"throttle"]) -> None: ...

global___UsagePlanApiStage = UsagePlanApiStage

@typing_extensions.final
class UsagePlanQuotaSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    limit: builtins.int
    offset: builtins.int
    period: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        limit: builtins.int = ...,
        offset: builtins.int = ...,
        period: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["limit", b"limit", "offset", b"offset", "period", b"period", "resource_info", b"resource_info"]) -> None: ...

global___UsagePlanQuotaSettings = UsagePlanQuotaSettings

@typing_extensions.final
class UsagePlanThrottleSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BURST_LIMIT_FIELD_NUMBER: builtins.int
    RATE_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    burst_limit: builtins.int
    rate_limit: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        burst_limit: builtins.int = ...,
        rate_limit: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["burst_limit", b"burst_limit", "rate_limit", b"rate_limit", "resource_info", b"resource_info"]) -> None: ...

global___UsagePlanThrottleSettings = UsagePlanThrottleSettings

@typing_extensions.final
class UsagePlan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    API_STAGES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    QUOTA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    THROTTLE_FIELD_NUMBER: builtins.int
    USAGE_PLAN_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def api_stages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsagePlanApiStage]: ...
    description: builtins.str
    @property
    def quota(self) -> global___UsagePlanQuotaSettings: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def throttle(self) -> global___UsagePlanThrottleSettings: ...
    usage_plan_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        api_stages: collections.abc.Iterable[global___UsagePlanApiStage] | None = ...,
        description: builtins.str = ...,
        quota: global___UsagePlanQuotaSettings | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        throttle: global___UsagePlanThrottleSettings | None = ...,
        usage_plan_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["quota", b"quota", "resource_info", b"resource_info", "throttle", b"throttle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_stages", b"api_stages", "description", b"description", "quota", b"quota", "resource_info", b"resource_info", "tags", b"tags", "throttle", b"throttle", "usage_plan_name", b"usage_plan_name"]) -> None: ...

global___UsagePlan = UsagePlan

@typing_extensions.final
class UsagePlanKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    KEY_TYPE_FIELD_NUMBER: builtins.int
    USAGE_PLAN_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key_id: builtins.str
    key_type: builtins.str
    usage_plan_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key_id: builtins.str = ...,
        key_type: builtins.str = ...,
        usage_plan_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_id", b"key_id", "key_type", b"key_type", "resource_info", b"resource_info", "usage_plan_id", b"usage_plan_id"]) -> None: ...

global___UsagePlanKey = UsagePlanKey

@typing_extensions.final
class VpcLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TARGET_ARNS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def target_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        target_arns: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "target_arns", b"target_arns"]) -> None: ...

global___VpcLink = VpcLink
